@@ -9,7 +9,7 @@
 
 package org.gnu.glib;
 
-//import java.util.logging.Logger;
+// import java.util.logging.Logger;
 
 import org.gnu.glib.Handle;
 import org.gnu.glib.Struct;
@@ -19,59 +19,59 @@ import org.gnu.glib.Struct;
  */
 public class Boxed extends Struct {
 
-    //private static final Logger log = Logger.getLogger("org.gnu.glib.Boxed");
+    // private static final Logger log = Logger.getLogger("org.gnu.glib.Boxed");
     /**
      * This class is only instantiable via subclasses.
      */
     protected Boxed() {
         // nothing to do
     }
-	
+
     protected Boxed(Handle handle) {
         super(handle);
     }
 
     /**
-     * Gets a <tt>Boxed</tt> instance for the given <tt>Handle</tt>.  If
-     * no Java object currently exists for the given <tt>Handle</tt>, this
-     * method will return <tt>null</tt>.  You should then instantiate the
-     * required Java class using the class' handle-constructor.  For example:
-     *
+     * Gets a <tt>Boxed</tt> instance for the given <tt>Handle</tt>. If no
+     * Java object currently exists for the given <tt>Handle</tt>, this
+     * method will return <tt>null</tt>. You should then instantiate the
+     * required Java class using the class' handle-constructor. For example:
+     * 
      * <pre>
      * // Get a Handle from somewhere (typically as a parameter to a method
      * // used as a callback and invoked from the C JNI side).
      * SomeGtkClass finalobj = null;
-     * Boxed obj = Boxed.getBoxedFromHandle( handle );
-     * if ( obj == null ) {
-     *     finalobj = new SomeGtkClass( handle );
+     * Boxed obj = Boxed.getBoxedFromHandle(handle);
+     * if (obj == null) {
+     *     finalobj = new SomeGtkClass(handle);
      * } else {
-     *     finalobj = (SomeGtkClass)obj;
+     *     finalobj = (SomeGtkClass) obj;
      * }
      * </pre>
-     *
-     * NOTE: This is for internal use only and should never need to be used
-     * in application code.
+     * 
+     * NOTE: This is for internal use only and should never need to be used in
+     * application code.
      */
-    public static Boxed getBoxedFromHandle( Handle hndl ) {
+    public static Boxed getBoxedFromHandle(Handle hndl) {
         return (Boxed) hndl.getProxiedObject();
     }
-    
+
     /**
      * Check if two objects refer to the same (native) object.
-     *
-     * @param other the reference object with which to compare.
+     * 
+     * @param other
+     *            the reference object with which to compare.
      * @return true if both objects refer to the same object.
      */
-    public boolean equals( Object other ){
-        return 
-            other instanceof Boxed && 
-            getHandle().equals( ((Boxed)other).getHandle() );
+    public boolean equals(Object other) {
+        return other instanceof Boxed
+                && getHandle().equals(((Boxed) other).getHandle());
     }
-	
+
     /**
-     * Returns a hash code value for the object. This allows for
-     * using Boxed objects as keys in hashmaps.
-     *
+     * Returns a hash code value for the object. This allows for using Boxed
+     * objects as keys in hashmaps.
+     * 
      * @return a hash code value for the object.
      */
     public int hashCode() {
@@ -79,8 +79,8 @@ public class Boxed extends Struct {
     }
 
     protected void finalize() throws Throwable {
-        //log.fine(this.getClass().getName());
-    	
+        // log.fine(this.getClass().getName());
+
         // If an exception is throws in the constructor of a sublcass, then
         // an object with a null handle may be finalized at some point. Don't
         // run nativeFinalize for those objects.
@@ -88,8 +88,7 @@ public class Boxed extends Struct {
             if (getHandle() != null) {
                 nativeFinalize(getHandle());
             }
-        }
-        finally {
+        } finally {
             super.finalize();
         }
     }
@@ -97,6 +96,8 @@ public class Boxed extends Struct {
     static {
         init();
     }
+
     native static final private void nativeFinalize(Handle handle);
+
     native static final private void init();
 }
