@@ -13,6 +13,7 @@
 #include <jg_jnu.h>
 #include "gtk_java.h"
 
+#include "org_gnu_gtk_Window.h"
 #ifdef __cplusplus
 extern "C" 
 {
@@ -432,7 +433,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Window_gtk_1window_1set_1icon_1list
 JNIEXPORT jobjectArray JNICALL Java_org_gnu_gtk_Window_gtk_1window_1get_1icon_1list (JNIEnv *env, jclass cls, jobject window) 
 {
     GtkWindow *window_g = (GtkWindow *)getPointerFromHandle(env, window);
-    return getGObjectHandlesFromGList(env, (GObject *) gtk_window_get_icon_list (window_g));
+    return getGObjectHandlesFromGList(env, gtk_window_get_icon_list (window_g));
 }
 
 /*
@@ -1049,6 +1050,15 @@ JNIEXPORT void JNICALL Java_org_gnu_gtk_Window_gtk_1window_1set_1default_1icon_1
     (*env)->ReleaseStringUTFChars(env, name, name_g);
 }
 
+JNIEXPORT void JNICALL Java_org_gnu_gtk_Window_gtk_1window_1destroy
+(JNIEnv *env, jclass cls, jobject window)
+{
+	GtkWindow *window_g;
+	window_g = getPointerFromHandle(env, window);
+	(* env)->DeleteGlobalRef(env, window);
+	gtk_object_destroy(GTK_OBJECT(window_g));
+}
+
 #ifdef __cplusplus
 }
 
